from django.conf import settings

from .utils import get_notifications


def data_templates(request):
    '''
    context_processors for get in all templates
    '''

    # Get notifications data
    notifications = get_notifications(request.user.id)

    return {
        'SETTINGS': settings,
        'notifications': notifications
    }


# -*- coding: utf-8 -*-
import datetime
from django.core.cache import cache
from . import settings


class ActiveUserMiddleware(object):
    """
    Set user authenticate
    """
    def process_request(self, request):
        current_user = request.user
        if request.user.is_authenticated():
            now = datetime.datetime.now()
            cache.set('seen_%s' % (current_user.username), now,
                           settings.USER_LASTSEEN_TIMEOUT)